==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GeographicTileSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicShapeSeriesBaseDescription } from "./GeographicShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let GeographicTileSeriesDescription = /*@__PURE__*/ (() => {
    class GeographicTileSeriesDescription extends GeographicShapeSeriesBaseDescription {
        constructor() {
            super();
            this.dt = null;
            this.dv = null;
        }
        get_type() {
            return "GeographicTileSeries";
        }
        get tileImagery() {
            return this.dt;
        }
        set tileImagery(a) {
            this.dt = a;
            this.e("TileImagery");
        }
        get imageTilesReadyRef() {
            return this.dv;
        }
        set imageTilesReadyRef(a) {
            this.dv = a;
            this.e("ImageTilesReadyRef");
        }
    }
    GeographicTileSeriesDescription.$t = /*@__PURE__*/ markType(GeographicTileSeriesDescription, 'GeographicTileSeriesDescription', GeographicShapeSeriesBaseDescription.$);
    return GeographicTileSeriesDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/GeographicTileSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicShapeSeriesBaseDescription } from "./GeographicShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let GeographicTileSeriesDescription = /*@__PURE__*/ (() => {
    class GeographicTileSeriesDescription extends GeographicShapeSeriesBaseDescription {
        get_type() {
            return "GeographicTileSeries";
        }
        constructor() {
            super();
            this.fx = null;
            this.fz = null;
        }
        get tileImagery() {
            return this.fx;
        }
        set tileImagery(a) {
            this.fx = a;
            this.g("TileImagery");
        }
        get imageTilesReadyRef() {
            return this.fz;
        }
        set imageTilesReadyRef(a) {
            this.fz = a;
            this.g("ImageTilesReadyRef");
        }
    }
    GeographicTileSeriesDescription.$t = /*@__PURE__*/ markType(GeographicTileSeriesDescription, 'GeographicTileSeriesDescription', GeographicShapeSeriesBaseDescription.$);
    return GeographicTileSeriesDescription;
})();
